;  Name: fsbeta
;  -----
;                     
;  Purpose :
;  --------
;     used for the computation of the the local Brunt-Vaisala frequency 
;	
;   Input : potential temperature tn, salinity sn
;   ------
;
;   References :
;   -----------
;	McDougall, T. J., J. Phys. Oceanogr., 17, 1950-1964, 1987.
;
;   Modifications :
;   --------------
;      Original  : 94-07 (G. Madec, M. Imbard)
;      Additions : 97-07 (G. Madec) introduction of statement functions
;      Idl version : 98-12 (M. Levy)
;----------------------------------------------------------------------
FUNCTION fsbeta,  pft,  pfs,  pfh
; 
; beta 
; ==== 
; 
;  fsbeta: saline expension coefficients 
;       pft :  potential temperature in degrees celcius 
;       pfs :  salinity anomaly (s-35) in psu 
;       pfh :  depth in meters 
; 
      z = $ 
       ( ( -0.415613e-09 * pft + 0.555579e-07 ) * pft $ 
                               - 0.301985e-05 ) * pft $ 
                               + 0.785567e-03 $ 
      +( 0.515032e-08 * pfs + 0.788212e-08 * pft - 0.356603e-06 ) * pfs $ 
      +(  (   0.121551e-17 * pfh $ 
            - 0.602281e-15 * pfs $ 
            - 0.175379e-14 * pft + 0.176621e-12 ) * pfh $ 
                                 + 0.408195e-10   * pfs $ 
         +( - 0.213127e-11 * pft + 0.192867e-09 ) * pft $  
                                 - 0.121555e-07 ) * pfh 
      return,  z
      end
